==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/panel/lxqt-panel_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>AddPluginDialog</name>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="14"/>
        <source>Add Plugins</source>
        <translation>Invoegtoepassingen toevoegen</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="22"/>
        <source>Search:</source>
        <translation>Zoeken:</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="98"/>
        <source>Add Widget</source>
        <translation>Bedieningselement invoegen</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="105"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.cpp" line="115"/>
        <source>(only one instance can run at a time)</source>
        <translation>(er kan slechts één exemplaar actief zijn)</translation>
    </message>
</context>
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="31"/>
        <source>Configure Panel</source>
        <translation>Werkbalk instellen</translation>
    </message>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="38"/>
        <source>Panel</source>
        <translation>Werkbalk</translation>
    </message>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="42"/>
        <source>Widgets</source>
        <translation>Bedieningselementen</translation>
    </message>
</context>
<context>
    <name>ConfigPanelWidget</name>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="20"/>
        <source>Configure panel</source>
        <translation>Werkbalk instellen</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="44"/>
        <source>Size</source>
        <translation>Grootte</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="68"/>
        <source>&lt;p&gt;Negative pixel value sets the panel length to that many pixels less than available screen space.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;E.g. &quot;Length&quot; set to -100px, screen size is 1000px, then real panel length will be 900 px.&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;Negatieve pixelwaarden stellen de werkbalklengte in op beschikbare schermruimte minus het opgegeven aantal pixels.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;Bijvoorbeeld bij &quot;Lengte&quot; ingesteld op -100px en een schermgrootte van 1000px, heeft de werkbalk een lengte van 900 px.&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="81"/>
        <source>Size:</source>
        <translation>Grootte:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="88"/>
        <source>Length:</source>
        <translation>Lengte:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="96"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="101"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="109"/>
        <location filename="../../../config/configpanelwidget.ui" line="153"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="166"/>
        <source>Icon size:</source>
        <translation>Symbolgröße:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="173"/>
        <source>Rows count:</source>
        <translation>Aantal rijen:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="202"/>
        <source>Alignment &amp;&amp; position</source>
        <translation>Uitlijning en positie</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="224"/>
        <location filename="../../../config/configpanelwidget.ui" line="250"/>
        <source>Zero means no animation</source>
        <translation>Nul betekent geen animatie</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="227"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="240"/>
        <source>Position:</source>
        <translation>Positie:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="253"/>
        <source>Animation duration:</source>
        <translation>Animatieduur:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="260"/>
        <source>Alignment:</source>
        <translation>Uitlijning:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="284"/>
        <location filename="../../../config/configpanelwidget.cpp" line="195"/>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="289"/>
        <location filename="../../../config/configpanelwidget.cpp" line="196"/>
        <location filename="../../../config/configpanelwidget.cpp" line="202"/>
        <source>Center</source>
        <translation>Midden</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="294"/>
        <location filename="../../../config/configpanelwidget.cpp" line="197"/>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="214"/>
        <source>Auto-hide</source>
        <translation>Automatisch verbergen</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="314"/>
        <source>Custom styling</source>
        <translation>Eigen stijl</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="335"/>
        <source>Font color:</source>
        <translation>Tekstkleur:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="375"/>
        <source>Background color:</source>
        <translation>Achtergrondkleur:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="414"/>
        <source>Background opacity:</source>
        <translation>Ondoorzichtigheid van achtergrond:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="446"/>
        <source>&lt;small&gt;Compositing is required for panel transparency.&lt;/small&gt;</source>
        <translation>&lt;small&gt;Voor een doorzichtige werkbalk is beeldsamenstelling benodigd.&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="474"/>
        <source>Background image:</source>
        <translation>Achtergrondafbeelding:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="161"/>
        <source>Top of desktop</source>
        <translation>Bovenkant van bureaublad</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="162"/>
        <source>Left of desktop</source>
        <translation>Linkerkant van bureaublad</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="163"/>
        <source>Right of desktop</source>
        <translation>Rechterkant van bureaublad</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="164"/>
        <source>Bottom of desktop</source>
        <translation>Onderkant van bureaublad</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="173"/>
        <source>Top of desktop %1</source>
        <translation>Bovenkant van bureaublad %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="174"/>
        <source>Left of desktop %1</source>
        <translation>Linkerkant van bureaublad %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="175"/>
        <source>Right of desktop %1</source>
        <translation>Rechterkant van bureaublad %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="176"/>
        <source>Bottom of desktop %1</source>
        <translation>Onderkant van bureaublad %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="201"/>
        <source>Top</source>
        <translation>Bovenaan</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="203"/>
        <source>Bottom</source>
        <translation>Onderaan</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="360"/>
        <location filename="../../../config/configpanelwidget.cpp" line="376"/>
        <source>Pick color</source>
        <translation>Kies kleur</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="394"/>
        <source>Pick image</source>
        <translation>Kies afbeelding</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="394"/>
        <source>Images (*.png *.gif *.jpg)</source>
        <translation>Afbeeldingen (*.png *.gif *.jpg)</translation>
    </message>
</context>
<context>
    <name>ConfigPluginsWidget</name>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="14"/>
        <source>Configure Plugins</source>
        <translation>Invoegtoepassingen instellen</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="84"/>
        <source>Note: changes made in this page cannot be reset.</source>
        <translation>Let op: hier gemaakte veranderingen kunnen niet ongedaan worden gemaakt.</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="112"/>
        <source>Move up</source>
        <translation>Naar boven verplaatsen</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="115"/>
        <location filename="../../../config/configpluginswidget.ui" line="129"/>
        <location filename="../../../config/configpluginswidget.ui" line="150"/>
        <location filename="../../../config/configpluginswidget.ui" line="164"/>
        <location filename="../../../config/configpluginswidget.ui" line="185"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="126"/>
        <source>Move down</source>
        <translation>Naar beneden verplaatsen</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="147"/>
        <source>Add</source>
        <translation>Toevoegen</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="161"/>
        <source>Remove</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="182"/>
        <source>Configure</source>
        <translation>Instellen</translation>
    </message>
</context>
<context>
    <name>LXQtPanel</name>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1012"/>
        <location filename="../../../lxqtpanel.cpp" line="1036"/>
        <source>Panel</source>
        <translation>Werkbalk</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1039"/>
        <source>Configure Panel</source>
        <translation>Werkbalk instellen</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1044"/>
        <source>Manage Widgets</source>
        <translation>Bedieningselementen beheren</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1050"/>
        <source>Add New Panel</source>
        <translation>Nieuwe werkbalk toevoegen</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1062"/>
        <source>Lock This Panel</source>
        <translation>Vergrendel deze werkbalk</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1200"/>
        <source>Removing a panel can not be undone.
Do you want to remove this panel?</source>
        <translation>Verwijdering van een werkbalk kan niet ongedaan worden gemaakt.
Wilt u deze werkbalk verwijderen?</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1057"/>
        <location filename="../../../lxqtpanel.cpp" line="1199"/>
        <source>Remove Panel</source>
        <translation>Werkbalk verwijderen</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../../../plugin.cpp" line="385"/>
        <source>Configure &quot;%1&quot;</source>
        <translation>&quot;%1&quot; instellen</translation>
    </message>
    <message>
        <location filename="../../../plugin.cpp" line="390"/>
        <source>Move &quot;%1&quot;</source>
        <translation>&quot;%1&quot; verplaatsen</translation>
    </message>
    <message>
        <location filename="../../../plugin.cpp" line="398"/>
        <source>Remove &quot;%1&quot;</source>
        <translation>&quot;%1&quot; verwijderen</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../../../lxqtpanelapplication.cpp" line="91"/>
        <source>Use alternate configuration file.</source>
        <translation>Gebruik alternatief instellingenbestand.</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanelapplication.cpp" line="92"/>
        <source>Configuration file</source>
        <translation>Instellingenbestand</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/panel/lxqt-panel_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>AddPluginDialog</name>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="14"/>
        <source>Add Plugins</source>
        <translation>Invoegtoepassingen toevoegen</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="22"/>
        <source>Search:</source>
        <translation>Zoeken:</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="98"/>
        <source>Add Widget</source>
        <translation>Bedieningselement invoegen</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.ui" line="105"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../../../config/addplugindialog.cpp" line="115"/>
        <source>(only one instance can run at a time)</source>
        <translation>(er kan slechts één exemplaar actief zijn)</translation>
    </message>
</context>
<context>
    <name>ConfigPanelDialog</name>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="31"/>
        <source>Configure Panel</source>
        <translation>Werkbalk instellen</translation>
    </message>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="38"/>
        <source>Panel</source>
        <translation>Werkbalk</translation>
    </message>
    <message>
        <location filename="../../../config/configpaneldialog.cpp" line="42"/>
        <source>Widgets</source>
        <translation>Bedieningselementen</translation>
    </message>
</context>
<context>
    <name>ConfigPanelWidget</name>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="20"/>
        <source>Configure panel</source>
        <translation>Werkbalk instellen</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="44"/>
        <source>Size</source>
        <translation>Grootte</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="68"/>
        <source>&lt;p&gt;Negative pixel value sets the panel length to that many pixels less than available screen space.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;E.g. &quot;Length&quot; set to -100px, screen size is 1000px, then real panel length will be 900 px.&lt;/i&gt;&lt;/p&gt;</source>
        <translation>&lt;p&gt;Negatieve pixelwaarden stellen de werkbalklengte in op beschikbare schermruimte minus het opgegeven aantal pixels.&lt;/p&gt;&lt;p/&gt;&lt;p&gt;&lt;i&gt;Bijvoorbeeld bij &quot;Lengte&quot; ingesteld op -100px en een schermgrootte van 1000px, heeft de werkbalk een lengte van 900 px.&lt;/i&gt;&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="81"/>
        <source>Size:</source>
        <translation>Grootte:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="88"/>
        <source>Length:</source>
        <translation>Lengte:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="96"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="101"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="109"/>
        <location filename="../../../config/configpanelwidget.ui" line="153"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="166"/>
        <source>Icon size:</source>
        <translation>Symbolgröße:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="173"/>
        <source>Rows count:</source>
        <translation>Aantal rijen:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="202"/>
        <source>Alignment &amp;&amp; position</source>
        <translation>Uitlijning en positie</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="250"/>
        <source>A&amp;uto-hide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="262"/>
        <location filename="../../../config/configpanelwidget.ui" line="285"/>
        <source>Zero means no animation</source>
        <translation>Nul betekent geen animatie</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="288"/>
        <location filename="../../../config/configpanelwidget.ui" line="314"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="301"/>
        <location filename="../../../config/configpanelwidget.ui" line="311"/>
        <source>Zero means no delay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="304"/>
        <source>Show with delay:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="330"/>
        <source>Don&apos;t allow maximized windows go under the panel window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="333"/>
        <source>Reserve space on display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="237"/>
        <source>Position:</source>
        <translation>Positie:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="265"/>
        <source>Animation duration:</source>
        <translation>Animatieduur:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="208"/>
        <source>Alignment:</source>
        <translation>Uitlijning:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="219"/>
        <location filename="../../../config/configpanelwidget.cpp" line="202"/>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="224"/>
        <location filename="../../../config/configpanelwidget.cpp" line="203"/>
        <location filename="../../../config/configpanelwidget.cpp" line="209"/>
        <source>Center</source>
        <translation>Midden</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="229"/>
        <location filename="../../../config/configpanelwidget.cpp" line="204"/>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <source>Auto-hide</source>
        <translation type="vanished">Automatisch verbergen</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="349"/>
        <source>Custom styling</source>
        <translation>Eigen stijl</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="370"/>
        <source>Font color:</source>
        <translation>Tekstkleur:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="410"/>
        <source>Background color:</source>
        <translation>Achtergrondkleur:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="449"/>
        <source>Background opacity:</source>
        <translation>Ondoorzichtigheid van achtergrond:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="481"/>
        <source>&lt;small&gt;Compositing is required for panel transparency.&lt;/small&gt;</source>
        <translation>&lt;small&gt;Voor een doorzichtige werkbalk is beeldsamenstelling benodigd.&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.ui" line="509"/>
        <source>Background image:</source>
        <translation>Achtergrondafbeelding:</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="168"/>
        <source>Top of desktop</source>
        <translation>Bovenkant van bureaublad</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="169"/>
        <source>Left of desktop</source>
        <translation>Linkerkant van bureaublad</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="170"/>
        <source>Right of desktop</source>
        <translation>Rechterkant van bureaublad</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="171"/>
        <source>Bottom of desktop</source>
        <translation>Onderkant van bureaublad</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="180"/>
        <source>Top of desktop %1</source>
        <translation>Bovenkant van bureaublad %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="181"/>
        <source>Left of desktop %1</source>
        <translation>Linkerkant van bureaublad %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="182"/>
        <source>Right of desktop %1</source>
        <translation>Rechterkant van bureaublad %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="183"/>
        <source>Bottom of desktop %1</source>
        <translation>Onderkant van bureaublad %1</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="208"/>
        <source>Top</source>
        <translation>Bovenaan</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="210"/>
        <source>Bottom</source>
        <translation>Onderaan</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="368"/>
        <location filename="../../../config/configpanelwidget.cpp" line="384"/>
        <source>Pick color</source>
        <translation>Kies kleur</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="402"/>
        <source>Pick image</source>
        <translation>Kies afbeelding</translation>
    </message>
    <message>
        <location filename="../../../config/configpanelwidget.cpp" line="402"/>
        <source>Images (*.png *.gif *.jpg)</source>
        <translation>Afbeeldingen (*.png *.gif *.jpg)</translation>
    </message>
</context>
<context>
    <name>ConfigPluginsWidget</name>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="14"/>
        <source>Configure Plugins</source>
        <translation>Invoegtoepassingen instellen</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="84"/>
        <source>Note: changes made in this page cannot be reset.</source>
        <translation>Let op: hier gemaakte veranderingen kunnen niet ongedaan worden gemaakt.</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="112"/>
        <source>Move up</source>
        <translation>Naar boven verplaatsen</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="115"/>
        <location filename="../../../config/configpluginswidget.ui" line="129"/>
        <location filename="../../../config/configpluginswidget.ui" line="150"/>
        <location filename="../../../config/configpluginswidget.ui" line="164"/>
        <location filename="../../../config/configpluginswidget.ui" line="185"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="126"/>
        <source>Move down</source>
        <translation>Naar beneden verplaatsen</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="147"/>
        <source>Add</source>
        <translation>Toevoegen</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="161"/>
        <source>Remove</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <location filename="../../../config/configpluginswidget.ui" line="182"/>
        <source>Configure</source>
        <translation>Instellen</translation>
    </message>
</context>
<context>
    <name>LXQtPanel</name>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1066"/>
        <location filename="../../../lxqtpanel.cpp" line="1091"/>
        <source>Panel</source>
        <translation>Werkbalk</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1094"/>
        <source>Configure Panel</source>
        <translation>Werkbalk instellen</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1099"/>
        <source>Manage Widgets</source>
        <translation>Bedieningselementen beheren</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1105"/>
        <source>Add New Panel</source>
        <translation>Nieuwe werkbalk toevoegen</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1112"/>
        <source>Remove Panel</source>
        <comment>Menu Item</comment>
        <translation type="unfinished">Werkbalk verwijderen</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1117"/>
        <source>Lock This Panel</source>
        <translation>Vergrendel deze werkbalk</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1259"/>
        <source>Remove Panel</source>
        <comment>Dialog Title</comment>
        <translation type="unfinished">Werkbalk verwijderen</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanel.cpp" line="1260"/>
        <source>Removing a panel can not be undone.
Do you want to remove this panel?</source>
        <translation>Verwijdering van een werkbalk kan niet ongedaan worden gemaakt.
Wilt u deze werkbalk verwijderen?</translation>
    </message>
    <message>
        <source>Remove Panel</source>
        <translation type="vanished">Werkbalk verwijderen</translation>
    </message>
</context>
<context>
    <name>Plugin</name>
    <message>
        <location filename="../../../plugin.cpp" line="416"/>
        <source>Configure &quot;%1&quot;</source>
        <translation>&quot;%1&quot; instellen</translation>
    </message>
    <message>
        <location filename="../../../plugin.cpp" line="421"/>
        <source>Move &quot;%1&quot;</source>
        <translation>&quot;%1&quot; verplaatsen</translation>
    </message>
    <message>
        <location filename="../../../plugin.cpp" line="429"/>
        <source>Remove &quot;%1&quot;</source>
        <translation>&quot;%1&quot; verwijderen</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../../../lxqtpanelapplication.cpp" line="95"/>
        <source>Use alternate configuration file.</source>
        <translation>Gebruik alternatief instellingenbestand.</translation>
    </message>
    <message>
        <location filename="../../../lxqtpanelapplication.cpp" line="96"/>
        <source>Configuration file</source>
        <translation>Instellingenbestand</translation>
    </message>
</context>
</TS>
